package Hawat::Controller::Admin;
use strict;
use warnings;
use Moose;
use namespace::autoclean;

use Data::Dumper;
use Mentat::Core qw(:c_hawat);

#-------------------------------------------------------------------------------
# Initialization section
#-------------------------------------------------------------------------------

BEGIN { extends 'Hawat::Controller::Secure'; }

__PACKAGE__->config(
    class       => 'Hawat::Controller::Admin',
    constructor => 'new',
);

=head1 NAME

Hawat::Controller::Admin - Catalyst controller for system administration

=head1 DESCRIPTION

Catalyst controller for handling actions related to system administration.

=head1 METHODS

=cut

#-------------------------------------------------------------------------------
# Implementation section
#-------------------------------------------------------------------------------

=head2 index

=cut

sub index :Path :Args(0) {
    my ( $self, $c ) = @_;
    $c->response->redirect($c->uri_for($self->action_for('dashboard')));
}

=head2 dashboard

Administration dashboard

=cut

sub dashboard :Local :Args(0) {
    my ($self, $c) = @_;

    my $database_name = $c->cfg('database_name');

    my $act_list = $c->model('Users')->list({'roles' => {'$nin' => ['user']}});
    my $nmb_list = $c->model('Users')->list({'groups' => {'$size' => 0}});
    my $run_logs = $c->model('Admin')->get_run_logs();

    $c->stash(ctime       => time,
              activations => $act_list,
              solitaires  => $nmb_list,
              run_logs    => $run_logs);

    # TODO: make use of 'nowrap' for ajax queries
    #$c->stash(nowrap => 1);

    # Optionally dump interesting variables - dependent on the devel switch
    $self->dump_variable($c, 'Stash', $c->stash) if $c->cfg('devel');

    # Render the view
    # NOTE: No need for that now, it will be rendered automagically, when the
    # 'end' method is called (see the Hawat::Controller::Secure for details)
    #$c->forward($c->view(HAWAT_VIEW_HTML));
}

=head2 db

Administration dashboard

=cut

sub db :Local :Args(0) {
    my ($self, $c) = @_;

    my $database_name = $c->cfg('database_name');

    my $db_stats = $c->model('Statistics')->get_stats_db($database_name, 'alerts', 'reports_ng', 'users', 'groups', 'events', 'logs', 'accesslogs', 'changelogs');
    my $al_stats = $c->model('Statistics')->get_stats_col_alerts($database_name);
    #my $db_stats = $c->model('Statistics')->get_stats_db($database_name, 'reports', 'users', 'groups', 'logs');

    $c->stash(database_name => $database_name, db_stats => $db_stats, al_stats => $al_stats);

    # TODO: make use of 'nowrap' for ajax queries
    #$c->stash(nowrap => 1);

    # Optionally dump interesting variables - dependent on the devel switch
    $self->dump_variable($c, 'Stash', $c->stash) if $c->cfg('devel');

    # Render the view
    # NOTE: No need for that now, it will be rendered automagically, when the
    # 'end' method is called (see the Hawat::Controller::Secure for details)
    #$c->forward($c->view(HAWAT_VIEW_HTML));
}

=head1 AUTHOR

 Jan Mach
 Cesnet, z.s.p.o
 jan.mach@cesnet.cz
 http://www.cesnet.cz

=head1 LICENSE

This library is free software. You can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

__PACKAGE__->meta->make_immutable;

1;
