package Hawat::Model::Dashboard;
use Moose;
use namespace::autoclean;

extends 'Catalyst::Model';

#-- Perl core modules ---------------------------------------------------------#
use Data::Dumper;

use Value::Convertor;
use Mentat::Stats::Dashboard;
use Mentat::Core qw(:c_hawat);

#-- CONSTANTS -----------------------------------------------------------------#

# Define meaningful default configuration values
use constant DFLT_FLAG_DEVEL        => 1;
use constant DFLT_NOSHOW            => 1;
use constant DFLT_DATABASE          => 'mentat';
use constant DFLT_COLLECTION        => 'alerts';
use constant DFLT_DATA_CACHE_FOLDER => "/var/mentat/cache";
use constant DFLT_DATA_CACHE_TTL    => 60*60*24*7;

# Load global configurations from config file
my $CFG_G = Hawat->config;

# Load module specific configurations from config file
my $CFG = $CFG_G->{"Model::Dashboard"};

# Setup global configurations
my $DEVEL               = (exists($CFG_G->{devel})) ? $CFG_G->{devel} : DFLT_FLAG_DEVEL();
my $NOSHOW              = (exists($CFG_G->{noshow})) ? $CFG_G->{noshow} : DFLT_NOSHOW();
my $DATABASE_NAME       = (exists($CFG_G->{database})) ? $CFG_G->{database} : DFLT_DATABASE();
my $COLLECTION_NAME     = (exists($CFG_G->{collection})) ? $CFG_G->{collection} : DFLT_COLLECTION();
my $DATA_CACHE_FOLDER   = (exists($CFG_G->{data_cache_folder})) ? $CFG_G->{data_cache_folder} : DFLT_DATA_CACHE_FOLDER();
my $DATA_CACHE_TTL      = (exists($CFG_G->{data_cache_ttl})) ? $CFG_G->{data_cache_ttl} : DFLT_DATA_CACHE_TTL();

__PACKAGE__->config(
    class       => 'Hawat::Model::Dashboard',
    constructor => 'new',
);

=head1 NAME

Hawat::Model::Dashboard - Catalyst Model

=head1 DESCRIPTION

Catalyst Model.

=head1 AUTHOR

root

=head1 LICENSE

This library is free software. You can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

use constant MODEL_USERS => "Users";

sub get_dashboard($$)
{
    my $self    = shift;
    croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;
    my ($id_users, $query, $from, $to) = @_;

    my $result = {};
    my $current_time = time();
    my $noshow = 0;

    unless (defined $from && length ($from > 0)) {
        $from = Value::Convertor->unixs_to_datestr($current_time - (7 * 24 * 60 * 60), 1);
        $noshow++;
    }
    unless (defined $to && length ($to > 0)) {
        $to = Value::Convertor->unixs_to_datestr($current_time, 1);
        $noshow++;
    }

    my $dashboard_stats = Mentat::Stats::Dashboard->new(
        database    => $DATABASE_NAME,
        collection  => $COLLECTION_NAME,
        cache       => $DATA_CACHE_FOLDER,
        ttl         => $DATA_CACHE_TTL
    );


    $result->{HAWAT_TABLE_BODY()} = Hawat->model(MODEL_USERS())->getDashboardQueries($id_users);
    $result->{HAWAT_FORM_INTERVALS()} = $dashboard_stats->get_intervals();
    $result->{HAWAT_FORM_FROM()}      = $from;
    $result->{HAWAT_FORM_TO()}        = $to;

    unless ($NOSHOW == 1 && $noshow > 0)
    {
        eval {
            my $tables = $dashboard_stats->get_table($query, $from, $to);

            if (defined $tables)
            {
                $result->{HAWAT_FORM_DATA()} = $tables;
            }
        };
        if ($@)
        {
            my $message = "Unable to load data for dashboard: $@";
            Log::Loger->error(__PACKAGE__, $message);
            $result->{HAWAT_FORM_ERROR()} = $message;
        }
    }

    return $result;

}

__PACKAGE__->meta->make_immutable;

1;
